# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/judge/participant_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/judge/participant_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.ecm import content_pb2 as eolymp_dot_ecm_dot_content__pb2
from eolymp.judge import participant_pb2 as eolymp_dot_judge_dot_participant__pb2
from eolymp.judge import result_pb2 as eolymp_dot_judge_dot_result__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&eolymp/judge/participant_service.proto\x12\x0c\x65olymp.judge\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x18\x65olymp/ecm/content.proto\x1a\x1e\x65olymp/judge/participant.proto\x1a\x19\x65olymp/judge/result.proto\x1a eolymp/wellknown/direction.proto\x1a!eolymp/wellknown/expression.proto\"\x82\x01\n\x17ParticipantChangedEvent\x12\x12\n\ncontest_id\x18\n \x01(\t\x12)\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x19.eolymp.judge.Participant\x12(\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x19.eolymp.judge.Participant\"\\\n\x16ParticipantJoinedEvent\x12\x12\n\ncontest_id\x18\n \x01(\t\x12.\n\x0bparticipant\x18\x02 \x01(\x0b\x32\x19.eolymp.judge.Participant\"\x85\x01\n\x19ParticipantFinalizedEvent\x12\x12\n\ncontest_id\x18\n \x01(\t\x12.\n\x0bparticipant\x18\x02 \x01(\x0b\x32\x19.eolymp.judge.Participant\x12$\n\x06result\x18\x03 \x01(\x0b\x32\x14.eolymp.judge.Result\"\x91\x02\n\x16\x41ssignParticipantInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x13\n\tmember_id\x18\n \x01(\tH\x00\x12\x12\n\x08group_id\x18\x0b \x01(\tH\x00\x12;\n\x05ghost\x18\x0c \x01(\x0b\x32*.eolymp.judge.AssignParticipantInput.GhostH\x00\x12\x12\n\nunofficial\x18\x14 \x01(\x08\x12\x10\n\x08inactive\x18\x15 \x01(\x08\x12,\n\x04role\x18\x1e \x01(\x0e\x32\x1e.eolymp.judge.Participant.Role\x1a\x1d\n\x05Ghost\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\tB\n\n\x08\x61ssignee\"1\n\x17\x41ssignParticipantOutput\x12\x16\n\x0eparticipant_id\x18\x01 \x01(\t\"D\n\x16\x45nableParticipantInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x16\n\x0eparticipant_id\x18\x02 \x01(\t\"\x19\n\x17\x45nableParticipantOutput\"E\n\x17\x44isableParticipantInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x16\n\x0eparticipant_id\x18\x02 \x01(\t\"\x1a\n\x18\x44isableParticipantOutput\"\xaa\x01\n\x16UpdateParticipantInput\x12\x34\n\x05patch\x18\x03 \x03(\x0e\x32%.eolymp.judge.Participant.Patch.Field\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x16\n\x0eparticipant_id\x18\x02 \x01(\t\x12.\n\x0bparticipant\x18\x04 \x01(\x0b\x32\x19.eolymp.judge.Participant\"\x19\n\x17UpdateParticipantOutput\"\x81\x01\n\x1a\x44isqualifyParticipantInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x16\n\x0eparticipant_id\x18\x02 \x01(\t\x12\x12\n\ndisqualify\x18\x03 \x01(\x08\x12#\n\x06reason\x18\x04 \x01(\x0b\x32\x13.eolymp.ecm.Content\"\x1d\n\x1b\x44isqualifyParticipantOutput\"D\n\x16\x44\x65leteParticipantInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x16\n\x0eparticipant_id\x18\x02 \x01(\t\"\x19\n\x17\x44\x65leteParticipantOutput\"F\n\x18\x44\x65scribeParticipantInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x16\n\x0eparticipant_id\x18\x02 \x01(\t\"K\n\x19\x44\x65scribeParticipantOutput\x12.\n\x0bparticipant\x18\x01 \x01(\x0b\x32\x19.eolymp.judge.Participant\"\xff\x06\n\x15ListParticipantsInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x0e\n\x06search\x18\x14 \x01(\t\x12;\n\x07\x66ilters\x18( \x01(\x0b\x32*.eolymp.judge.ListParticipantsInput.Filter\x12:\n\x04sort\x18\x32 \x01(\x0e\x32,.eolymp.judge.ListParticipantsInput.Sortable\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x1a\xc3\x04\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x31\n\tmember_id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x08group_id\x18\x04 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x06status\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x39\n\nstarted_at\x18\x06 \x03(\x0b\x32%.eolymp.wellknown.ExpressionTimestamp\x12\x34\n\nunofficial\x18\n \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x36\n\x0c\x64isqualified\x18\x0b \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x32\n\x08inactive\x18\x0c \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12.\n\x04role\x18\r \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12/\n\x05staff\x18\x0e \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x38\n\x0ehas_violations\x18\x0f \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\"9\n\x08Sortable\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x10\n\x0c\x44ISPLAY_NAME\x10\x01\x12\x0e\n\nSTARTED_AT\x10\x02\"Q\n\x16ListParticipantsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12(\n\x05items\x18\x02 \x03(\x0b\x32\x19.eolymp.judge.Participant\"C\n\x15WatchParticipantInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x16\n\x0eparticipant_id\x18\x02 \x01(\t\"H\n\x16WatchParticipantOutput\x12.\n\x0bparticipant\x18\x01 \x01(\x0b\x32\x19.eolymp.judge.Participant\")\n\x13\x44\x65scribeViewerInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"F\n\x14\x44\x65scribeViewerOutput\x12.\n\x0bparticipant\x18\x01 \x01(\x0b\x32\x19.eolymp.judge.Participant\"&\n\x10JoinContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"\x13\n\x11JoinContestOutput\"\'\n\x11StartContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"\x14\n\x12StartContestOutput\"\'\n\x11PauseContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"\x14\n\x12PauseContestOutput\"(\n\x12\x46inishContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"\x15\n\x13\x46inishContestOutput2\xcb\x11\n\x12ParticipantService\x12\xa1\x01\n\x11\x41ssignParticipant\x12$.eolymp.judge.AssignParticipantInput\x1a%.eolymp.judge.AssignParticipantOutput\"?\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02\x0f\"\r/participants\x12\xb9\x01\n\x11\x45nableParticipant\x12$.eolymp.judge.EnableParticipantInput\x1a%.eolymp.judge.EnableParticipantOutput\"W\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02\'\"%/participants/{participant_id}/enable\x12\xbd\x01\n\x12\x44isableParticipant\x12%.eolymp.judge.DisableParticipantInput\x1a&.eolymp.judge.DisableParticipantOutput\"X\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02(\"&/participants/{participant_id}/disable\x12\xb2\x01\n\x11UpdateParticipant\x12$.eolymp.judge.UpdateParticipantInput\x1a%.eolymp.judge.UpdateParticipantOutput\"P\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02 \x1a\x1e/participants/{participant_id}\x12\xc9\x01\n\x15\x44isqualifyParticipant\x12(.eolymp.judge.DisqualifyParticipantInput\x1a).eolymp.judge.DisqualifyParticipantOutput\"[\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02+\")/participants/{participant_id}/disqualify\x12\xb2\x01\n\x11\x44\x65leteParticipant\x12$.eolymp.judge.DeleteParticipantInput\x1a%.eolymp.judge.DeleteParticipantOutput\"P\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02 *\x1e/participants/{participant_id}\x12\xb8\x01\n\x13\x44\x65scribeParticipant\x12&.eolymp.judge.DescribeParticipantInput\x1a\'.eolymp.judge.DescribeParticipantOutput\"P\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xc8\x01\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02 \x12\x1e/participants/{participant_id}\x12\x9d\x01\n\x10ListParticipants\x12#.eolymp.judge.ListParticipantsInput\x1a$.eolymp.judge.ListParticipantsOutput\">\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02\x0f\x12\r/participants\x12{\n\x10WatchParticipant\x12#.eolymp.judge.WatchParticipantInput\x1a$.eolymp.judge.WatchParticipantOutput\"\x1a\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read0\x01\x12l\n\x0bJoinContest\x12\x1e.eolymp.judge.JoinContestInput\x1a\x1f.eolymp.judge.JoinContestOutput\"\x1c\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x03\x82\xd3\xe4\x93\x02\x07\"\x05/join\x12{\n\x0e\x44\x65scribeViewer\x12!.eolymp.judge.DescribeViewerInput\x1a\".eolymp.judge.DescribeViewerOutput\"\"\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\r\x12\x0b/introspect\x12\x91\x01\n\x0cStartContest\x12\x1f.eolymp.judge.StartContestInput\x1a .eolymp.judge.StartContestOutput\">\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x03\x82\xe3\n\x1d\x8a\xe3\n\x19judge:contest:participate\x82\xd3\xe4\x93\x02\x08\"\x06/start\x12\x91\x01\n\x0cPauseContest\x12\x1f.eolymp.judge.PauseContestInput\x1a .eolymp.judge.PauseContestOutput\">\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x03\x82\xe3\n\x1d\x8a\xe3\n\x19judge:contest:participate\x82\xd3\xe4\x93\x02\x08\"\x06/pause\x12t\n\rFinishContest\x12 .eolymp.judge.FinishContestInput\x1a!.eolymp.judge.FinishContestOutput\"\x1e\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\t\x12\x07/finishB-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.participant_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _globals['_PARTICIPANTSERVICE'].methods_by_name['AssignParticipant']._loaded_options = None
  _globals['_PARTICIPANTSERVICE'].methods_by_name['AssignParticipant']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002\017\"\r/participants'
  _globals['_PARTICIPANTSERVICE'].methods_by_name['EnableParticipant']._loaded_options = None
  _globals['_PARTICIPANTSERVICE'].methods_by_name['EnableParticipant']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002\'\"%/participants/{participant_id}/enable'
  _globals['_PARTICIPANTSERVICE'].methods_by_name['DisableParticipant']._loaded_options = None
  _globals['_PARTICIPANTSERVICE'].methods_by_name['DisableParticipant']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002(\"&/participants/{participant_id}/disable'
  _globals['_PARTICIPANTSERVICE'].methods_by_name['UpdateParticipant']._loaded_options = None
  _globals['_PARTICIPANTSERVICE'].methods_by_name['UpdateParticipant']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002 \032\036/participants/{participant_id}'
  _globals['_PARTICIPANTSERVICE'].methods_by_name['DisqualifyParticipant']._loaded_options = None
  _globals['_PARTICIPANTSERVICE'].methods_by_name['DisqualifyParticipant']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002+\")/participants/{participant_id}/disqualify'
  _globals['_PARTICIPANTSERVICE'].methods_by_name['DeleteParticipant']._loaded_options = None
  _globals['_PARTICIPANTSERVICE'].methods_by_name['DeleteParticipant']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002 *\036/participants/{participant_id}'
  _globals['_PARTICIPANTSERVICE'].methods_by_name['DescribeParticipant']._loaded_options = None
  _globals['_PARTICIPANTSERVICE'].methods_by_name['DescribeParticipant']._serialized_options = b'\352\342\n\014\365\342\n\000\000HB\370\342\n\310\001\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002 \022\036/participants/{participant_id}'
  _globals['_PARTICIPANTSERVICE'].methods_by_name['ListParticipants']._loaded_options = None
  _globals['_PARTICIPANTSERVICE'].methods_by_name['ListParticipants']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002\017\022\r/participants'
  _globals['_PARTICIPANTSERVICE'].methods_by_name['WatchParticipant']._loaded_options = None
  _globals['_PARTICIPANTSERVICE'].methods_by_name['WatchParticipant']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read'
  _globals['_PARTICIPANTSERVICE'].methods_by_name['JoinContest']._loaded_options = None
  _globals['_PARTICIPANTSERVICE'].methods_by_name['JoinContest']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\003\202\323\344\223\002\007\"\005/join'
  _globals['_PARTICIPANTSERVICE'].methods_by_name['DescribeViewer']._loaded_options = None
  _globals['_PARTICIPANTSERVICE'].methods_by_name['DescribeViewer']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\r\022\013/introspect'
  _globals['_PARTICIPANTSERVICE'].methods_by_name['StartContest']._loaded_options = None
  _globals['_PARTICIPANTSERVICE'].methods_by_name['StartContest']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\003\202\343\n\035\212\343\n\031judge:contest:participate\202\323\344\223\002\010\"\006/start'
  _globals['_PARTICIPANTSERVICE'].methods_by_name['PauseContest']._loaded_options = None
  _globals['_PARTICIPANTSERVICE'].methods_by_name['PauseContest']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\003\202\343\n\035\212\343\n\031judge:contest:participate\202\323\344\223\002\010\"\006/pause'
  _globals['_PARTICIPANTSERVICE'].methods_by_name['FinishContest']._loaded_options = None
  _globals['_PARTICIPANTSERVICE'].methods_by_name['FinishContest']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\t\022\007/finish'
  _globals['_PARTICIPANTCHANGEDEVENT']._serialized_start=310
  _globals['_PARTICIPANTCHANGEDEVENT']._serialized_end=440
  _globals['_PARTICIPANTJOINEDEVENT']._serialized_start=442
  _globals['_PARTICIPANTJOINEDEVENT']._serialized_end=534
  _globals['_PARTICIPANTFINALIZEDEVENT']._serialized_start=537
  _globals['_PARTICIPANTFINALIZEDEVENT']._serialized_end=670
  _globals['_ASSIGNPARTICIPANTINPUT']._serialized_start=673
  _globals['_ASSIGNPARTICIPANTINPUT']._serialized_end=946
  _globals['_ASSIGNPARTICIPANTINPUT_GHOST']._serialized_start=905
  _globals['_ASSIGNPARTICIPANTINPUT_GHOST']._serialized_end=934
  _globals['_ASSIGNPARTICIPANTOUTPUT']._serialized_start=948
  _globals['_ASSIGNPARTICIPANTOUTPUT']._serialized_end=997
  _globals['_ENABLEPARTICIPANTINPUT']._serialized_start=999
  _globals['_ENABLEPARTICIPANTINPUT']._serialized_end=1067
  _globals['_ENABLEPARTICIPANTOUTPUT']._serialized_start=1069
  _globals['_ENABLEPARTICIPANTOUTPUT']._serialized_end=1094
  _globals['_DISABLEPARTICIPANTINPUT']._serialized_start=1096
  _globals['_DISABLEPARTICIPANTINPUT']._serialized_end=1165
  _globals['_DISABLEPARTICIPANTOUTPUT']._serialized_start=1167
  _globals['_DISABLEPARTICIPANTOUTPUT']._serialized_end=1193
  _globals['_UPDATEPARTICIPANTINPUT']._serialized_start=1196
  _globals['_UPDATEPARTICIPANTINPUT']._serialized_end=1366
  _globals['_UPDATEPARTICIPANTOUTPUT']._serialized_start=1368
  _globals['_UPDATEPARTICIPANTOUTPUT']._serialized_end=1393
  _globals['_DISQUALIFYPARTICIPANTINPUT']._serialized_start=1396
  _globals['_DISQUALIFYPARTICIPANTINPUT']._serialized_end=1525
  _globals['_DISQUALIFYPARTICIPANTOUTPUT']._serialized_start=1527
  _globals['_DISQUALIFYPARTICIPANTOUTPUT']._serialized_end=1556
  _globals['_DELETEPARTICIPANTINPUT']._serialized_start=1558
  _globals['_DELETEPARTICIPANTINPUT']._serialized_end=1626
  _globals['_DELETEPARTICIPANTOUTPUT']._serialized_start=1628
  _globals['_DELETEPARTICIPANTOUTPUT']._serialized_end=1653
  _globals['_DESCRIBEPARTICIPANTINPUT']._serialized_start=1655
  _globals['_DESCRIBEPARTICIPANTINPUT']._serialized_end=1725
  _globals['_DESCRIBEPARTICIPANTOUTPUT']._serialized_start=1727
  _globals['_DESCRIBEPARTICIPANTOUTPUT']._serialized_end=1802
  _globals['_LISTPARTICIPANTSINPUT']._serialized_start=1805
  _globals['_LISTPARTICIPANTSINPUT']._serialized_end=2700
  _globals['_LISTPARTICIPANTSINPUT_FILTER']._serialized_start=2062
  _globals['_LISTPARTICIPANTSINPUT_FILTER']._serialized_end=2641
  _globals['_LISTPARTICIPANTSINPUT_SORTABLE']._serialized_start=2643
  _globals['_LISTPARTICIPANTSINPUT_SORTABLE']._serialized_end=2700
  _globals['_LISTPARTICIPANTSOUTPUT']._serialized_start=2702
  _globals['_LISTPARTICIPANTSOUTPUT']._serialized_end=2783
  _globals['_WATCHPARTICIPANTINPUT']._serialized_start=2785
  _globals['_WATCHPARTICIPANTINPUT']._serialized_end=2852
  _globals['_WATCHPARTICIPANTOUTPUT']._serialized_start=2854
  _globals['_WATCHPARTICIPANTOUTPUT']._serialized_end=2926
  _globals['_DESCRIBEVIEWERINPUT']._serialized_start=2928
  _globals['_DESCRIBEVIEWERINPUT']._serialized_end=2969
  _globals['_DESCRIBEVIEWEROUTPUT']._serialized_start=2971
  _globals['_DESCRIBEVIEWEROUTPUT']._serialized_end=3041
  _globals['_JOINCONTESTINPUT']._serialized_start=3043
  _globals['_JOINCONTESTINPUT']._serialized_end=3081
  _globals['_JOINCONTESTOUTPUT']._serialized_start=3083
  _globals['_JOINCONTESTOUTPUT']._serialized_end=3102
  _globals['_STARTCONTESTINPUT']._serialized_start=3104
  _globals['_STARTCONTESTINPUT']._serialized_end=3143
  _globals['_STARTCONTESTOUTPUT']._serialized_start=3145
  _globals['_STARTCONTESTOUTPUT']._serialized_end=3165
  _globals['_PAUSECONTESTINPUT']._serialized_start=3167
  _globals['_PAUSECONTESTINPUT']._serialized_end=3206
  _globals['_PAUSECONTESTOUTPUT']._serialized_start=3208
  _globals['_PAUSECONTESTOUTPUT']._serialized_end=3228
  _globals['_FINISHCONTESTINPUT']._serialized_start=3230
  _globals['_FINISHCONTESTINPUT']._serialized_end=3270
  _globals['_FINISHCONTESTOUTPUT']._serialized_start=3272
  _globals['_FINISHCONTESTOUTPUT']._serialized_end=3293
  _globals['_PARTICIPANTSERVICE']._serialized_start=3296
  _globals['_PARTICIPANTSERVICE']._serialized_end=5547
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/community/penalty.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/community/penalty.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.ecm import content_pb2 as eolymp_dot_ecm_dot_content__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x65olymp/community/penalty.proto\x12\x10\x65olymp.community\x1a\x18\x65olymp/ecm/content.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb7\x02\n\x07Penalty\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07summary\x18\x02 \x01(\t\x12(\n\x0b\x64\x65scription\x18\x03 \x01(\x0b\x32\x13.eolymp.ecm.Content\x12\r\n\x05scope\x18\x14 \x03(\t\x12.\n\ncreated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nexpires_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0c\x63\x61ncelled_at\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"D\n\x05\x45xtra\x12\x0c\n\x08NO_EXTRA\x10\x00\x12\x15\n\x11\x44\x45SCRIPTION_VALUE\x10\x01\x12\x16\n\x12\x44\x45SCRIPTION_RENDER\x10\x02\x42\x35Z3github.com/eolymp/go-sdk/eolymp/community;communityb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.community.penalty_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/community;community'
  _globals['_PENALTY']._serialized_start=112
  _globals['_PENALTY']._serialized_end=423
  _globals['_PENALTY_EXTRA']._serialized_start=355
  _globals['_PENALTY_EXTRA']._serialized_end=423
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/auth/sso_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/auth/sso_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.auth import linked_account_pb2 as eolymp_dot_auth_dot_linked__account__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x65olymp/auth/sso_service.proto\x12\x0b\x65olymp.auth\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a eolymp/auth/linked_account.proto\"Y\n\x12SignonRequestInput\x12-\n\x04type\x18\x01 \x01(\x0e\x32\x1f.eolymp.auth.LinkedAccount.Type\x12\x14\n\x0c\x63\x61llback_uri\x18\x02 \x01(\t\"+\n\x13SignonRequestOutput\x12\x14\n\x0credirect_uri\x18\x01 \x01(\t\"2\n\x13SignonExchangeInput\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\r\n\x05state\x18\x02 \x01(\t\"k\n\x14SignonExchangeOutput\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x12\n\ntoken_type\x18\x02 \x01(\t\x12\x12\n\nexpires_in\x18\x03 \x01(\r\x12\x15\n\rrefresh_token\x18\x04 \x01(\t2\x82\x02\n\nSSOService\x12w\n\rSignonRequest\x12\x1f.eolymp.auth.SignonRequestInput\x1a .eolymp.auth.SignonRequestOutput\"#\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x0e\"\x0c/sso:request\x12{\n\x0eSignonExchange\x12 .eolymp.auth.SignonExchangeInput\x1a!.eolymp.auth.SignonExchangeOutput\"$\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x0f\"\r/sso:exchangeB+Z)github.com/eolymp/go-sdk/eolymp/auth;authb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.auth.sso_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/eolymp/go-sdk/eolymp/auth;auth'
  _globals['_SSOSERVICE'].methods_by_name['SignonRequest']._loaded_options = None
  _globals['_SSOSERVICE'].methods_by_name['SignonRequest']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\016\"\014/sso:request'
  _globals['_SSOSERVICE'].methods_by_name['SignonExchange']._loaded_options = None
  _globals['_SSOSERVICE'].methods_by_name['SignonExchange']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\017\"\r/sso:exchange'
  _globals['_SIGNONREQUESTINPUT']._serialized_start=147
  _globals['_SIGNONREQUESTINPUT']._serialized_end=236
  _globals['_SIGNONREQUESTOUTPUT']._serialized_start=238
  _globals['_SIGNONREQUESTOUTPUT']._serialized_end=281
  _globals['_SIGNONEXCHANGEINPUT']._serialized_start=283
  _globals['_SIGNONEXCHANGEINPUT']._serialized_end=333
  _globals['_SIGNONEXCHANGEOUTPUT']._serialized_start=335
  _globals['_SIGNONEXCHANGEOUTPUT']._serialized_end=442
  _globals['_SSOSERVICE']._serialized_start=445
  _globals['_SSOSERVICE']._serialized_end=703
# @@protoc_insertion_point(module_scope)



import datetime

from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Job(_message.Message):
    __slots__ = ("id", "status", "user_id", "member_id", "document_url", "created_at", "updated_at")
    class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_STATUS: _ClassVar[Job.Status]
        PENDING: _ClassVar[Job.Status]
        PRINTING: _ClassVar[Job.Status]
        COMPLETE: _ClassVar[Job.Status]
        ERROR: _ClassVar[Job.Status]
        CANCELLED: _ClassVar[Job.Status]
    UNKNOWN_STATUS: Job.Status
    PENDING: Job.Status
    PRINTING: Job.Status
    COMPLETE: Job.Status
    ERROR: Job.Status
    CANCELLED: Job.Status
    ID_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    DOCUMENT_URL_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    status: Job.Status
    user_id: str
    member_id: str
    document_url: str
    created_at: _timestamp_pb2.Timestamp
    updated_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., status: _Optional[_Union[Job.Status, str]] = ..., user_id: _Optional[str] = ..., member_id: _Optional[str] = ..., document_url: _Optional[str] = ..., created_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.auth import linked_account_pb2 as _linked_account_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RequestLinkedAccountInput(_message.Message):
    __slots__ = ("type", "callback_uri")
    TYPE_FIELD_NUMBER: _ClassVar[int]
    CALLBACK_URI_FIELD_NUMBER: _ClassVar[int]
    type: _linked_account_pb2.LinkedAccount.Type
    callback_uri: str
    def __init__(self, type: _Optional[_Union[_linked_account_pb2.LinkedAccount.Type, str]] = ..., callback_uri: _Optional[str] = ...) -> None: ...

class RequestLinkedAccountOutput(_message.Message):
    __slots__ = ("redirect_uri",)
    REDIRECT_URI_FIELD_NUMBER: _ClassVar[int]
    redirect_uri: str
    def __init__(self, redirect_uri: _Optional[str] = ...) -> None: ...

class CreateLinkedAccountInput(_message.Message):
    __slots__ = ("code", "state")
    CODE_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    code: str
    state: str
    def __init__(self, code: _Optional[str] = ..., state: _Optional[str] = ...) -> None: ...

class CreateLinkedAccountOutput(_message.Message):
    __slots__ = ("link_id",)
    LINK_ID_FIELD_NUMBER: _ClassVar[int]
    link_id: str
    def __init__(self, link_id: _Optional[str] = ...) -> None: ...

class DeleteLinkedAccountInput(_message.Message):
    __slots__ = ("link_id",)
    LINK_ID_FIELD_NUMBER: _ClassVar[int]
    link_id: str
    def __init__(self, link_id: _Optional[str] = ...) -> None: ...

class DeleteLinkedAccountOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DescribeLinkedAccountInput(_message.Message):
    __slots__ = ("link_id",)
    LINK_ID_FIELD_NUMBER: _ClassVar[int]
    link_id: str
    def __init__(self, link_id: _Optional[str] = ...) -> None: ...

class DescribeLinkedAccountOutput(_message.Message):
    __slots__ = ("link",)
    LINK_FIELD_NUMBER: _ClassVar[int]
    link: _linked_account_pb2.LinkedAccount
    def __init__(self, link: _Optional[_Union[_linked_account_pb2.LinkedAccount, _Mapping]] = ...) -> None: ...

class ListLinkedAccountsInput(_message.Message):
    __slots__ = ("offset", "size", "filters")
    class Filter(_message.Message):
        __slots__ = ("id", "type")
        ID_FIELD_NUMBER: _ClassVar[int]
        TYPE_FIELD_NUMBER: _ClassVar[int]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        type: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        def __init__(self, id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., type: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ...) -> None: ...
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    offset: int
    size: int
    filters: ListLinkedAccountsInput.Filter
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListLinkedAccountsInput.Filter, _Mapping]] = ...) -> None: ...

class ListLinkedAccountsOutput(_message.Message):
    __slots__ = ("total", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_linked_account_pb2.LinkedAccount]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_linked_account_pb2.LinkedAccount, _Mapping]]] = ...) -> None: ...



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.ecm import node_pb2 as _node_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DebugAssistanceMessage(_message.Message):
    __slots__ = ("id", "locale", "message", "rating")
    ID_FIELD_NUMBER: _ClassVar[int]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    RATING_FIELD_NUMBER: _ClassVar[int]
    id: str
    locale: str
    message: _node_pb2.Node
    rating: int
    def __init__(self, id: _Optional[str] = ..., locale: _Optional[str] = ..., message: _Optional[_Union[_node_pb2.Node, _Mapping]] = ..., rating: _Optional[int] = ...) -> None: ...

class RequestDebugAssistanceInput(_message.Message):
    __slots__ = ("submission_id", "locale")
    SUBMISSION_ID_FIELD_NUMBER: _ClassVar[int]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    submission_id: str
    locale: str
    def __init__(self, submission_id: _Optional[str] = ..., locale: _Optional[str] = ...) -> None: ...

class RequestDebugAssistanceOutput(_message.Message):
    __slots__ = ("message",)
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    message: DebugAssistanceMessage
    def __init__(self, message: _Optional[_Union[DebugAssistanceMessage, _Mapping]] = ...) -> None: ...

class DescribeDebugAssistanceInput(_message.Message):
    __slots__ = ("submission_id",)
    SUBMISSION_ID_FIELD_NUMBER: _ClassVar[int]
    submission_id: str
    def __init__(self, submission_id: _Optional[str] = ...) -> None: ...

class DescribeDebugAssistanceOutput(_message.Message):
    __slots__ = ("message",)
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    message: DebugAssistanceMessage
    def __init__(self, message: _Optional[_Union[DebugAssistanceMessage, _Mapping]] = ...) -> None: ...

class RateDebugAssistanceInput(_message.Message):
    __slots__ = ("submission_id", "rating")
    SUBMISSION_ID_FIELD_NUMBER: _ClassVar[int]
    RATING_FIELD_NUMBER: _ClassVar[int]
    submission_id: str
    rating: int
    def __init__(self, submission_id: _Optional[str] = ..., rating: _Optional[int] = ...) -> None: ...

class RateDebugAssistanceOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.judge import contest_pb2 as _contest_pb2
from eolymp.ranker import scoreboard_pb2 as _scoreboard_pb2
from eolymp.universe import space_pb2 as _space_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Authorization(_message.Message):
    __slots__ = ()
    class OAuth2(_message.Message):
        __slots__ = ("client_id", "token_endpoint", "authorize_endpoint", "userinfo_endpoint", "signout_endpoint")
        CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
        TOKEN_ENDPOINT_FIELD_NUMBER: _ClassVar[int]
        AUTHORIZE_ENDPOINT_FIELD_NUMBER: _ClassVar[int]
        USERINFO_ENDPOINT_FIELD_NUMBER: _ClassVar[int]
        SIGNOUT_ENDPOINT_FIELD_NUMBER: _ClassVar[int]
        client_id: str
        token_endpoint: str
        authorize_endpoint: str
        userinfo_endpoint: str
        signout_endpoint: str
        def __init__(self, client_id: _Optional[str] = ..., token_endpoint: _Optional[str] = ..., authorize_endpoint: _Optional[str] = ..., userinfo_endpoint: _Optional[str] = ..., signout_endpoint: _Optional[str] = ...) -> None: ...
    def __init__(self) -> None: ...

class Record(_message.Message):
    __slots__ = ("target",)
    class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNSPECIFIED: _ClassVar[Record.Type]
        SPACE: _ClassVar[Record.Type]
        CONTEST: _ClassVar[Record.Type]
        SCOREBOARD: _ClassVar[Record.Type]
    UNSPECIFIED: Record.Type
    SPACE: Record.Type
    CONTEST: Record.Type
    SCOREBOARD: Record.Type
    class Target(_message.Message):
        __slots__ = ("type", "url")
        TYPE_FIELD_NUMBER: _ClassVar[int]
        URL_FIELD_NUMBER: _ClassVar[int]
        type: Record.Type
        url: str
        def __init__(self, type: _Optional[_Union[Record.Type, str]] = ..., url: _Optional[str] = ...) -> None: ...
    TARGET_FIELD_NUMBER: _ClassVar[int]
    target: Record.Target
    def __init__(self, target: _Optional[_Union[Record.Target, _Mapping]] = ...) -> None: ...

class ResolveNameInput(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class ResolveNameOutput(_message.Message):
    __slots__ = ("target", "space", "contest", "scoreboard", "oauth2")
    TARGET_FIELD_NUMBER: _ClassVar[int]
    SPACE_FIELD_NUMBER: _ClassVar[int]
    CONTEST_FIELD_NUMBER: _ClassVar[int]
    SCOREBOARD_FIELD_NUMBER: _ClassVar[int]
    OAUTH2_FIELD_NUMBER: _ClassVar[int]
    target: Record.Target
    space: _space_pb2.Space
    contest: _contest_pb2.Contest
    scoreboard: _scoreboard_pb2.Scoreboard
    oauth2: Authorization.OAuth2
    def __init__(self, target: _Optional[_Union[Record.Target, _Mapping]] = ..., space: _Optional[_Union[_space_pb2.Space, _Mapping]] = ..., contest: _Optional[_Union[_contest_pb2.Contest, _Mapping]] = ..., scoreboard: _Optional[_Union[_scoreboard_pb2.Scoreboard, _Mapping]] = ..., oauth2: _Optional[_Union[Authorization.OAuth2, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/atlas/suggestion_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/atlas/suggestion_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.atlas import suggestion_pb2 as eolymp_dot_atlas_dot_suggestion__pb2
from eolymp.ecm import content_pb2 as eolymp_dot_ecm_dot_content__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%eolymp/atlas/suggestion_service.proto\x12\x0c\x65olymp.atlas\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1d\x65olymp/atlas/suggestion.proto\x1a\x18\x65olymp/ecm/content.proto\x1a!eolymp/wellknown/expression.proto\"\x7f\n\x16SuggestionChangedEvent\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12(\n\x06\x62\x65\x66ore\x18\x02 \x01(\x0b\x32\x18.eolymp.atlas.Suggestion\x12\'\n\x05\x61\x66ter\x18\x03 \x01(\x0b\x32\x18.eolymp.atlas.Suggestion\"E\n\x15\x43reateSuggestionInput\x12,\n\nsuggestion\x18\x02 \x01(\x0b\x32\x18.eolymp.atlas.Suggestion\"/\n\x16\x43reateSuggestionOutput\x12\x15\n\rsuggestion_id\x18\x01 \x01(\t\"\\\n\x15UpdateSuggestionInput\x12\x15\n\rsuggestion_id\x18\x02 \x01(\t\x12,\n\nsuggestion\x18\x03 \x01(\x0b\x32\x18.eolymp.atlas.Suggestion\"\x18\n\x16UpdateSuggestionOutput\".\n\x15\x44\x65leteSuggestionInput\x12\x15\n\rsuggestion_id\x18\x02 \x01(\t\"\x18\n\x16\x44\x65leteSuggestionOutput\"\x85\x01\n\x15ReviewSuggestionInput\x12\x15\n\rsuggestion_id\x18\x02 \x01(\t\x12/\n\x06status\x18\x03 \x01(\x0e\x32\x1f.eolymp.atlas.Suggestion.Status\x12$\n\x07\x63omment\x18\x04 \x01(\x0b\x32\x13.eolymp.ecm.Content\"\x18\n\x16ReviewSuggestionOutput\"0\n\x17ResubmitSuggestionInput\x12\x15\n\rsuggestion_id\x18\x02 \x01(\t\"\x1a\n\x18ResubmitSuggestionOutput\"\x8c\x02\n\x14ListSuggestionsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12:\n\x07\x66ilters\x18( \x01(\x0b\x32).eolymp.atlas.ListSuggestionsInput.Filter\x1a\x99\x01\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x31\n\tmember_id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x06status\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"O\n\x15ListSuggestionsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\'\n\x05items\x18\x02 \x03(\x0b\x32\x18.eolymp.atlas.Suggestion\"0\n\x17\x44\x65scribeSuggestionInput\x12\x15\n\rsuggestion_id\x18\x02 \x01(\t\"H\n\x18\x44\x65scribeSuggestionOutput\x12,\n\nsuggestion\x18\x01 \x01(\x0b\x32\x18.eolymp.atlas.Suggestion2\x9e\x08\n\x11SuggestionService\x12\x82\x01\n\x10\x43reateSuggestion\x12#.eolymp.atlas.CreateSuggestionInput\x1a$.eolymp.atlas.CreateSuggestionOutput\"#\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x0e\"\x0c/suggestions\x12\x92\x01\n\x10UpdateSuggestion\x12#.eolymp.atlas.UpdateSuggestionInput\x1a$.eolymp.atlas.UpdateSuggestionOutput\"3\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1e\"\x1c/suggestions/{suggestion_id}\x12\x99\x01\n\x10ReviewSuggestion\x12#.eolymp.atlas.ReviewSuggestionInput\x1a$.eolymp.atlas.ReviewSuggestionOutput\":\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02%\"#/suggestions/{suggestion_id}/review\x12\xa1\x01\n\x12ResubmitSuggestion\x12%.eolymp.atlas.ResubmitSuggestionInput\x1a&.eolymp.atlas.ResubmitSuggestionOutput\"<\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\'\"%/suggestions/{suggestion_id}/resubmit\x12\x92\x01\n\x10\x44\x65leteSuggestion\x12#.eolymp.atlas.DeleteSuggestionInput\x1a$.eolymp.atlas.DeleteSuggestionOutput\"3\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1e*\x1c/suggestions/{suggestion_id}\x12\x7f\n\x0fListSuggestions\x12\".eolymp.atlas.ListSuggestionsInput\x1a#.eolymp.atlas.ListSuggestionsOutput\"#\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x0e\x12\x0c/suggestions\x12\x98\x01\n\x12\x44\x65scribeSuggestion\x12%.eolymp.atlas.DescribeSuggestionInput\x1a&.eolymp.atlas.DescribeSuggestionOutput\"3\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x1e\x12\x1c/suggestions/{suggestion_id}B-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.suggestion_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _globals['_SUGGESTIONSERVICE'].methods_by_name['CreateSuggestion']._loaded_options = None
  _globals['_SUGGESTIONSERVICE'].methods_by_name['CreateSuggestion']._serialized_options = b'\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\016\"\014/suggestions'
  _globals['_SUGGESTIONSERVICE'].methods_by_name['UpdateSuggestion']._loaded_options = None
  _globals['_SUGGESTIONSERVICE'].methods_by_name['UpdateSuggestion']._serialized_options = b'\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\036\"\034/suggestions/{suggestion_id}'
  _globals['_SUGGESTIONSERVICE'].methods_by_name['ReviewSuggestion']._loaded_options = None
  _globals['_SUGGESTIONSERVICE'].methods_by_name['ReviewSuggestion']._serialized_options = b'\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002%\"#/suggestions/{suggestion_id}/review'
  _globals['_SUGGESTIONSERVICE'].methods_by_name['ResubmitSuggestion']._loaded_options = None
  _globals['_SUGGESTIONSERVICE'].methods_by_name['ResubmitSuggestion']._serialized_options = b'\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\'\"%/suggestions/{suggestion_id}/resubmit'
  _globals['_SUGGESTIONSERVICE'].methods_by_name['DeleteSuggestion']._loaded_options = None
  _globals['_SUGGESTIONSERVICE'].methods_by_name['DeleteSuggestion']._serialized_options = b'\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\036*\034/suggestions/{suggestion_id}'
  _globals['_SUGGESTIONSERVICE'].methods_by_name['ListSuggestions']._loaded_options = None
  _globals['_SUGGESTIONSERVICE'].methods_by_name['ListSuggestions']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\016\022\014/suggestions'
  _globals['_SUGGESTIONSERVICE'].methods_by_name['DescribeSuggestion']._loaded_options = None
  _globals['_SUGGESTIONSERVICE'].methods_by_name['DescribeSuggestion']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\036\022\034/suggestions/{suggestion_id}'
  _globals['_SUGGESTIONCHANGEDEVENT']._serialized_start=214
  _globals['_SUGGESTIONCHANGEDEVENT']._serialized_end=341
  _globals['_CREATESUGGESTIONINPUT']._serialized_start=343
  _globals['_CREATESUGGESTIONINPUT']._serialized_end=412
  _globals['_CREATESUGGESTIONOUTPUT']._serialized_start=414
  _globals['_CREATESUGGESTIONOUTPUT']._serialized_end=461
  _globals['_UPDATESUGGESTIONINPUT']._serialized_start=463
  _globals['_UPDATESUGGESTIONINPUT']._serialized_end=555
  _globals['_UPDATESUGGESTIONOUTPUT']._serialized_start=557
  _globals['_UPDATESUGGESTIONOUTPUT']._serialized_end=581
  _globals['_DELETESUGGESTIONINPUT']._serialized_start=583
  _globals['_DELETESUGGESTIONINPUT']._serialized_end=629
  _globals['_DELETESUGGESTIONOUTPUT']._serialized_start=631
  _globals['_DELETESUGGESTIONOUTPUT']._serialized_end=655
  _globals['_REVIEWSUGGESTIONINPUT']._serialized_start=658
  _globals['_REVIEWSUGGESTIONINPUT']._serialized_end=791
  _globals['_REVIEWSUGGESTIONOUTPUT']._serialized_start=793
  _globals['_REVIEWSUGGESTIONOUTPUT']._serialized_end=817
  _globals['_RESUBMITSUGGESTIONINPUT']._serialized_start=819
  _globals['_RESUBMITSUGGESTIONINPUT']._serialized_end=867
  _globals['_RESUBMITSUGGESTIONOUTPUT']._serialized_start=869
  _globals['_RESUBMITSUGGESTIONOUTPUT']._serialized_end=895
  _globals['_LISTSUGGESTIONSINPUT']._serialized_start=898
  _globals['_LISTSUGGESTIONSINPUT']._serialized_end=1166
  _globals['_LISTSUGGESTIONSINPUT_FILTER']._serialized_start=1013
  _globals['_LISTSUGGESTIONSINPUT_FILTER']._serialized_end=1166
  _globals['_LISTSUGGESTIONSOUTPUT']._serialized_start=1168
  _globals['_LISTSUGGESTIONSOUTPUT']._serialized_end=1247
  _globals['_DESCRIBESUGGESTIONINPUT']._serialized_start=1249
  _globals['_DESCRIBESUGGESTIONINPUT']._serialized_end=1297
  _globals['_DESCRIBESUGGESTIONOUTPUT']._serialized_start=1299
  _globals['_DESCRIBESUGGESTIONOUTPUT']._serialized_end=1371
  _globals['_SUGGESTIONSERVICE']._serialized_start=1374
  _globals['_SUGGESTIONSERVICE']._serialized_end=2428
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.webhook import webhook_pb2 as _webhook_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateWebhookInput(_message.Message):
    __slots__ = ("webhook",)
    WEBHOOK_FIELD_NUMBER: _ClassVar[int]
    webhook: _webhook_pb2.Webhook
    def __init__(self, webhook: _Optional[_Union[_webhook_pb2.Webhook, _Mapping]] = ...) -> None: ...

class CreateWebhookOutput(_message.Message):
    __slots__ = ("webhook_id",)
    WEBHOOK_ID_FIELD_NUMBER: _ClassVar[int]
    webhook_id: str
    def __init__(self, webhook_id: _Optional[str] = ...) -> None: ...

class UpdateWebhookInput(_message.Message):
    __slots__ = ("patch", "webhook_id", "webhook")
    PATCH_FIELD_NUMBER: _ClassVar[int]
    WEBHOOK_ID_FIELD_NUMBER: _ClassVar[int]
    WEBHOOK_FIELD_NUMBER: _ClassVar[int]
    patch: _containers.RepeatedScalarFieldContainer[_webhook_pb2.Webhook.Patch]
    webhook_id: str
    webhook: _webhook_pb2.Webhook
    def __init__(self, patch: _Optional[_Iterable[_Union[_webhook_pb2.Webhook.Patch, str]]] = ..., webhook_id: _Optional[str] = ..., webhook: _Optional[_Union[_webhook_pb2.Webhook, _Mapping]] = ...) -> None: ...

class UpdateWebhookOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DeleteWebhookInput(_message.Message):
    __slots__ = ("webhook_id",)
    WEBHOOK_ID_FIELD_NUMBER: _ClassVar[int]
    webhook_id: str
    def __init__(self, webhook_id: _Optional[str] = ...) -> None: ...

class DeleteWebhookOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DescribeWebhookInput(_message.Message):
    __slots__ = ("webhook_id",)
    WEBHOOK_ID_FIELD_NUMBER: _ClassVar[int]
    webhook_id: str
    def __init__(self, webhook_id: _Optional[str] = ...) -> None: ...

class DescribeWebhookOutput(_message.Message):
    __slots__ = ("webhook",)
    WEBHOOK_FIELD_NUMBER: _ClassVar[int]
    webhook: _webhook_pb2.Webhook
    def __init__(self, webhook: _Optional[_Union[_webhook_pb2.Webhook, _Mapping]] = ...) -> None: ...

class ListWebhooksInput(_message.Message):
    __slots__ = ("size", "offset")
    SIZE_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    size: int
    offset: int
    def __init__(self, size: _Optional[int] = ..., offset: _Optional[int] = ...) -> None: ...

class ListWebhooksOutput(_message.Message):
    __slots__ = ("total", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_webhook_pb2.Webhook]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_webhook_pb2.Webhook, _Mapping]]] = ...) -> None: ...

class TestWebhookInput(_message.Message):
    __slots__ = ("webhook_id",)
    WEBHOOK_ID_FIELD_NUMBER: _ClassVar[int]
    webhook_id: str
    def __init__(self, webhook_id: _Optional[str] = ...) -> None: ...

class TestWebhookOutput(_message.Message):
    __slots__ = ("status", "response")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_FIELD_NUMBER: _ClassVar[int]
    status: int
    response: str
    def __init__(self, status: _Optional[int] = ..., response: _Optional[str] = ...) -> None: ...



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.content import fragment_pb2 as _fragment_pb2
from eolymp.content import variant_pb2 as _variant_pb2
from eolymp.wellknown import direction_pb2 as _direction_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DescribeFragmentInput(_message.Message):
    __slots__ = ("fragment_id", "extra")
    FRAGMENT_ID_FIELD_NUMBER: _ClassVar[int]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    fragment_id: str
    extra: _containers.RepeatedScalarFieldContainer[_fragment_pb2.Fragment.Extra]
    def __init__(self, fragment_id: _Optional[str] = ..., extra: _Optional[_Iterable[_Union[_fragment_pb2.Fragment.Extra, str]]] = ...) -> None: ...

class DescribeFragmentOutput(_message.Message):
    __slots__ = ("fragment",)
    FRAGMENT_FIELD_NUMBER: _ClassVar[int]
    fragment: _fragment_pb2.Fragment
    def __init__(self, fragment: _Optional[_Union[_fragment_pb2.Fragment, _Mapping]] = ...) -> None: ...

class ListFragmentsInput(_message.Message):
    __slots__ = ("offset", "size", "filters", "sort", "order", "locale", "extra")
    class Sort(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        DEFAULT: _ClassVar[ListFragmentsInput.Sort]
        PATH: _ClassVar[ListFragmentsInput.Sort]
        CREATED_AT: _ClassVar[ListFragmentsInput.Sort]
    DEFAULT: ListFragmentsInput.Sort
    PATH: ListFragmentsInput.Sort
    CREATED_AT: ListFragmentsInput.Sort
    class Filter(_message.Message):
        __slots__ = ("query", "id", "path", "locale", "label")
        QUERY_FIELD_NUMBER: _ClassVar[int]
        ID_FIELD_NUMBER: _ClassVar[int]
        PATH_FIELD_NUMBER: _ClassVar[int]
        LOCALE_FIELD_NUMBER: _ClassVar[int]
        LABEL_FIELD_NUMBER: _ClassVar[int]
        query: str
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        path: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionString]
        locale: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        label: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        def __init__(self, query: _Optional[str] = ..., id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., path: _Optional[_Iterable[_Union[_expression_pb2.ExpressionString, _Mapping]]] = ..., locale: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ..., label: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ...) -> None: ...
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    SORT_FIELD_NUMBER: _ClassVar[int]
    ORDER_FIELD_NUMBER: _ClassVar[int]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    offset: int
    size: int
    filters: ListFragmentsInput.Filter
    sort: ListFragmentsInput.Sort
    order: _direction_pb2.Direction
    locale: str
    extra: _containers.RepeatedScalarFieldContainer[_fragment_pb2.Fragment.Extra]
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListFragmentsInput.Filter, _Mapping]] = ..., sort: _Optional[_Union[ListFragmentsInput.Sort, str]] = ..., order: _Optional[_Union[_direction_pb2.Direction, str]] = ..., locale: _Optional[str] = ..., extra: _Optional[_Iterable[_Union[_fragment_pb2.Fragment.Extra, str]]] = ...) -> None: ...

class ListFragmentsOutput(_message.Message):
    __slots__ = ("total", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_fragment_pb2.Fragment]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_fragment_pb2.Fragment, _Mapping]]] = ...) -> None: ...

class CreateFragmentInput(_message.Message):
    __slots__ = ("fragment",)
    FRAGMENT_FIELD_NUMBER: _ClassVar[int]
    fragment: _fragment_pb2.Fragment
    def __init__(self, fragment: _Optional[_Union[_fragment_pb2.Fragment, _Mapping]] = ...) -> None: ...

class CreateFragmentOutput(_message.Message):
    __slots__ = ("fragment_id",)
    FRAGMENT_ID_FIELD_NUMBER: _ClassVar[int]
    fragment_id: str
    def __init__(self, fragment_id: _Optional[str] = ...) -> None: ...

class UpdateFragmentInput(_message.Message):
    __slots__ = ("patch", "fragment_id", "fragment")
    PATCH_FIELD_NUMBER: _ClassVar[int]
    FRAGMENT_ID_FIELD_NUMBER: _ClassVar[int]
    FRAGMENT_FIELD_NUMBER: _ClassVar[int]
    patch: _containers.RepeatedScalarFieldContainer[_fragment_pb2.Fragment.Patch]
    fragment_id: str
    fragment: _fragment_pb2.Fragment
    def __init__(self, patch: _Optional[_Iterable[_Union[_fragment_pb2.Fragment.Patch, str]]] = ..., fragment_id: _Optional[str] = ..., fragment: _Optional[_Union[_fragment_pb2.Fragment, _Mapping]] = ...) -> None: ...

class UpdateFragmentOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DeleteFragmentInput(_message.Message):
    __slots__ = ("fragment_id",)
    FRAGMENT_ID_FIELD_NUMBER: _ClassVar[int]
    fragment_id: str
    def __init__(self, fragment_id: _Optional[str] = ...) -> None: ...

class DeleteFragmentOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class TranslateFragmentInput(_message.Message):
    __slots__ = ("fragment_id", "source", "target", "target_automatic", "override_manual")
    FRAGMENT_ID_FIELD_NUMBER: _ClassVar[int]
    SOURCE_FIELD_NUMBER: _ClassVar[int]
    TARGET_FIELD_NUMBER: _ClassVar[int]
    TARGET_AUTOMATIC_FIELD_NUMBER: _ClassVar[int]
    OVERRIDE_MANUAL_FIELD_NUMBER: _ClassVar[int]
    fragment_id: str
    source: str
    target: _containers.RepeatedScalarFieldContainer[str]
    target_automatic: bool
    override_manual: bool
    def __init__(self, fragment_id: _Optional[str] = ..., source: _Optional[str] = ..., target: _Optional[_Iterable[str]] = ..., target_automatic: bool = ..., override_manual: bool = ...) -> None: ...

class TranslateFragmentOutput(_message.Message):
    __slots__ = ("job_id",)
    JOB_ID_FIELD_NUMBER: _ClassVar[int]
    job_id: str
    def __init__(self, job_id: _Optional[str] = ...) -> None: ...

class DescribeVariantInput(_message.Message):
    __slots__ = ("fragment_id", "variant_id", "extra")
    FRAGMENT_ID_FIELD_NUMBER: _ClassVar[int]
    VARIANT_ID_FIELD_NUMBER: _ClassVar[int]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    fragment_id: str
    variant_id: str
    extra: _containers.RepeatedScalarFieldContainer[_variant_pb2.Variant.Extra]
    def __init__(self, fragment_id: _Optional[str] = ..., variant_id: _Optional[str] = ..., extra: _Optional[_Iterable[_Union[_variant_pb2.Variant.Extra, str]]] = ...) -> None: ...

class DescribeVariantOutput(_message.Message):
    __slots__ = ("variant",)
    VARIANT_FIELD_NUMBER: _ClassVar[int]
    variant: _variant_pb2.Variant
    def __init__(self, variant: _Optional[_Union[_variant_pb2.Variant, _Mapping]] = ...) -> None: ...

class ListVariantsInput(_message.Message):
    __slots__ = ("fragment_id", "offset", "size", "filters", "extra")
    class Filter(_message.Message):
        __slots__ = ("query", "id", "locale")
        QUERY_FIELD_NUMBER: _ClassVar[int]
        ID_FIELD_NUMBER: _ClassVar[int]
        LOCALE_FIELD_NUMBER: _ClassVar[int]
        query: str
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        locale: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        def __init__(self, query: _Optional[str] = ..., id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., locale: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ...) -> None: ...
    FRAGMENT_ID_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    fragment_id: str
    offset: int
    size: int
    filters: ListVariantsInput.Filter
    extra: _containers.RepeatedScalarFieldContainer[_variant_pb2.Variant.Extra]
    def __init__(self, fragment_id: _Optional[str] = ..., offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListVariantsInput.Filter, _Mapping]] = ..., extra: _Optional[_Iterable[_Union[_variant_pb2.Variant.Extra, str]]] = ...) -> None: ...

class ListVariantsOutput(_message.Message):
    __slots__ = ("total", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_variant_pb2.Variant]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_variant_pb2.Variant, _Mapping]]] = ...) -> None: ...

class CreateVariantInput(_message.Message):
    __slots__ = ("fragment_id", "variant")
    FRAGMENT_ID_FIELD_NUMBER: _ClassVar[int]
    VARIANT_FIELD_NUMBER: _ClassVar[int]
    fragment_id: str
    variant: _variant_pb2.Variant
    def __init__(self, fragment_id: _Optional[str] = ..., variant: _Optional[_Union[_variant_pb2.Variant, _Mapping]] = ...) -> None: ...

class CreateVariantOutput(_message.Message):
    __slots__ = ("variant_id",)
    VARIANT_ID_FIELD_NUMBER: _ClassVar[int]
    variant_id: str
    def __init__(self, variant_id: _Optional[str] = ...) -> None: ...

class UpdateVariantInput(_message.Message):
    __slots__ = ("fragment_id", "variant_id", "variant")
    FRAGMENT_ID_FIELD_NUMBER: _ClassVar[int]
    VARIANT_ID_FIELD_NUMBER: _ClassVar[int]
    VARIANT_FIELD_NUMBER: _ClassVar[int]
    fragment_id: str
    variant_id: str
    variant: _variant_pb2.Variant
    def __init__(self, fragment_id: _Optional[str] = ..., variant_id: _Optional[str] = ..., variant: _Optional[_Union[_variant_pb2.Variant, _Mapping]] = ...) -> None: ...

class UpdateVariantOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DeleteVariantInput(_message.Message):
    __slots__ = ("fragment_id", "variant_id")
    FRAGMENT_ID_FIELD_NUMBER: _ClassVar[int]
    VARIANT_ID_FIELD_NUMBER: _ClassVar[int]
    fragment_id: str
    variant_id: str
    def __init__(self, fragment_id: _Optional[str] = ..., variant_id: _Optional[str] = ...) -> None: ...

class DeleteVariantOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DescribePathInput(_message.Message):
    __slots__ = ("path", "locale", "extra")
    PATH_FIELD_NUMBER: _ClassVar[int]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    path: str
    locale: str
    extra: _containers.RepeatedScalarFieldContainer[_fragment_pb2.Fragment.Extra]
    def __init__(self, path: _Optional[str] = ..., locale: _Optional[str] = ..., extra: _Optional[_Iterable[_Union[_fragment_pb2.Fragment.Extra, str]]] = ...) -> None: ...

class DescribePathOutput(_message.Message):
    __slots__ = ("fragment",)
    FRAGMENT_FIELD_NUMBER: _ClassVar[int]
    fragment: _fragment_pb2.Fragment
    def __init__(self, fragment: _Optional[_Union[_fragment_pb2.Fragment, _Mapping]] = ...) -> None: ...

class ListParentsInput(_message.Message):
    __slots__ = ("path", "locale", "extra")
    PATH_FIELD_NUMBER: _ClassVar[int]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    path: str
    locale: str
    extra: _containers.RepeatedScalarFieldContainer[_fragment_pb2.Fragment.Extra]
    def __init__(self, path: _Optional[str] = ..., locale: _Optional[str] = ..., extra: _Optional[_Iterable[_Union[_fragment_pb2.Fragment.Extra, str]]] = ...) -> None: ...

class ListParentsOutput(_message.Message):
    __slots__ = ("total", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_fragment_pb2.Fragment]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_fragment_pb2.Fragment, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/judge/medal.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/judge/medal.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x65olymp/judge/medal.proto\x12\x0c\x65olymp.judge*`\n\x05Medal\x12\x0c\n\x08NO_MEDAL\x10\x00\x12\x0e\n\nGOLD_MEDAL\x10\x01\x12\x10\n\x0cSILVER_MEDAL\x10\x02\x12\x10\n\x0c\x42RONZE_MEDAL\x10\x03\x12\x15\n\x11HONORABLE_MENTION\x10\x04\x42-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.medal_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _globals['_MEDAL']._serialized_start=42
  _globals['_MEDAL']._serialized_end=138
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/course/events.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/course/events.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.course import assignment_pb2 as eolymp_dot_course_dot_assignment__pb2
from eolymp.course import material_pb2 as eolymp_dot_course_dot_material__pb2
from eolymp.course import module_pb2 as eolymp_dot_course_dot_module__pb2
from eolymp.course import student_pb2 as eolymp_dot_course_dot_student__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x65olymp/course/events.proto\x12\reolymp.course\x1a\x1e\x65olymp/course/assignment.proto\x1a\x1c\x65olymp/course/material.proto\x1a\x1a\x65olymp/course/module.proto\x1a\x1b\x65olymp/course/student.proto\"t\n\x12ModuleChangedEvent\x12\x11\n\tcourse_id\x18\x01 \x01(\t\x12%\n\x06\x62\x65\x66ore\x18\x02 \x01(\x0b\x32\x15.eolymp.course.Module\x12$\n\x05\x61\x66ter\x18\x03 \x01(\x0b\x32\x15.eolymp.course.Module\"z\n\x14MaterialChangedEvent\x12\x11\n\tcourse_id\x18\x01 \x01(\t\x12\'\n\x06\x62\x65\x66ore\x18\x03 \x01(\x0b\x32\x17.eolymp.course.Material\x12&\n\x05\x61\x66ter\x18\x04 \x01(\x0b\x32\x17.eolymp.course.Material\"w\n\x13StudentChangedEvent\x12\x11\n\tcourse_id\x18\x01 \x01(\t\x12&\n\x06\x62\x65\x66ore\x18\x02 \x01(\x0b\x32\x16.eolymp.course.Student\x12%\n\x05\x61\x66ter\x18\x03 \x01(\x0b\x32\x16.eolymp.course.Student\"\x93\x01\n\x16\x41ssignmentChangedEvent\x12\x11\n\tcourse_id\x18\x01 \x01(\t\x12\x11\n\tmodule_id\x18\x02 \x01(\t\x12)\n\x06\x62\x65\x66ore\x18\x03 \x01(\x0b\x32\x19.eolymp.course.Assignment\x12(\n\x05\x61\x66ter\x18\x04 \x01(\x0b\x32\x19.eolymp.course.AssignmentB/Z-github.com/eolymp/go-sdk/eolymp/course;courseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.course.events_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/course;course'
  _globals['_MODULECHANGEDEVENT']._serialized_start=164
  _globals['_MODULECHANGEDEVENT']._serialized_end=280
  _globals['_MATERIALCHANGEDEVENT']._serialized_start=282
  _globals['_MATERIALCHANGEDEVENT']._serialized_end=404
  _globals['_STUDENTCHANGEDEVENT']._serialized_start=406
  _globals['_STUDENTCHANGEDEVENT']._serialized_end=525
  _globals['_ASSIGNMENTCHANGEDEVENT']._serialized_start=528
  _globals['_ASSIGNMENTCHANGEDEVENT']._serialized_end=675
# @@protoc_insertion_point(module_scope)



from eolymp.executor import stats_pb2 as _stats_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class EvaluationReport(_message.Message):
    __slots__ = ("task_id", "reference", "origin", "metadata", "agent", "signature", "version", "type", "status", "error_message", "runs")
    class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_STATUS: _ClassVar[EvaluationReport.Status]
        PENDING: _ClassVar[EvaluationReport.Status]
        PROVISIONING: _ClassVar[EvaluationReport.Status]
        INITIALIZING: _ClassVar[EvaluationReport.Status]
        EXECUTING: _ClassVar[EvaluationReport.Status]
        COMPLETE: _ClassVar[EvaluationReport.Status]
        ERROR: _ClassVar[EvaluationReport.Status]
        FAILED: _ClassVar[EvaluationReport.Status]
    UNKNOWN_STATUS: EvaluationReport.Status
    PENDING: EvaluationReport.Status
    PROVISIONING: EvaluationReport.Status
    INITIALIZING: EvaluationReport.Status
    EXECUTING: EvaluationReport.Status
    COMPLETE: EvaluationReport.Status
    ERROR: EvaluationReport.Status
    FAILED: EvaluationReport.Status
    class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_TYPE: _ClassVar[EvaluationReport.Type]
        TYPE_UPDATE: _ClassVar[EvaluationReport.Type]
        TYPE_ERROR: _ClassVar[EvaluationReport.Type]
        TYPE_FAILURE: _ClassVar[EvaluationReport.Type]
    UNKNOWN_TYPE: EvaluationReport.Type
    TYPE_UPDATE: EvaluationReport.Type
    TYPE_ERROR: EvaluationReport.Type
    TYPE_FAILURE: EvaluationReport.Type
    class Run(_message.Message):
        __slots__ = ("reference", "status", "score", "cost", "time_usage", "time_limit", "cpu_usage", "cpu_limit", "memory_usage", "memory_limit", "time_coefficient", "input_url", "output_url", "answer_url", "debug_stats", "checker_stats", "interactor_stats")
        class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = ()
            NONE: _ClassVar[EvaluationReport.Run.Status]
            PENDING: _ClassVar[EvaluationReport.Run.Status]
            EXECUTING: _ClassVar[EvaluationReport.Run.Status]
            TIMEOUT: _ClassVar[EvaluationReport.Run.Status]
            CPU_EXHAUSTED: _ClassVar[EvaluationReport.Run.Status]
            MEMORY_OVERFLOW: _ClassVar[EvaluationReport.Run.Status]
            RUNTIME_ERROR: _ClassVar[EvaluationReport.Run.Status]
            EXECUTED: _ClassVar[EvaluationReport.Run.Status]
            ACCEPTED: _ClassVar[EvaluationReport.Run.Status]
            WRONG_ANSWER: _ClassVar[EvaluationReport.Run.Status]
            VERIFICATION_FAILURE: _ClassVar[EvaluationReport.Run.Status]
            SKIPPED: _ClassVar[EvaluationReport.Run.Status]
            INTERACTION_FAILURE: _ClassVar[EvaluationReport.Run.Status]
            BLOCKED: _ClassVar[EvaluationReport.Run.Status]
        NONE: EvaluationReport.Run.Status
        PENDING: EvaluationReport.Run.Status
        EXECUTING: EvaluationReport.Run.Status
        TIMEOUT: EvaluationReport.Run.Status
        CPU_EXHAUSTED: EvaluationReport.Run.Status
        MEMORY_OVERFLOW: EvaluationReport.Run.Status
        RUNTIME_ERROR: EvaluationReport.Run.Status
        EXECUTED: EvaluationReport.Run.Status
        ACCEPTED: EvaluationReport.Run.Status
        WRONG_ANSWER: EvaluationReport.Run.Status
        VERIFICATION_FAILURE: EvaluationReport.Run.Status
        SKIPPED: EvaluationReport.Run.Status
        INTERACTION_FAILURE: EvaluationReport.Run.Status
        BLOCKED: EvaluationReport.Run.Status
        REFERENCE_FIELD_NUMBER: _ClassVar[int]
        STATUS_FIELD_NUMBER: _ClassVar[int]
        SCORE_FIELD_NUMBER: _ClassVar[int]
        COST_FIELD_NUMBER: _ClassVar[int]
        TIME_USAGE_FIELD_NUMBER: _ClassVar[int]
        TIME_LIMIT_FIELD_NUMBER: _ClassVar[int]
        CPU_USAGE_FIELD_NUMBER: _ClassVar[int]
        CPU_LIMIT_FIELD_NUMBER: _ClassVar[int]
        MEMORY_USAGE_FIELD_NUMBER: _ClassVar[int]
        MEMORY_LIMIT_FIELD_NUMBER: _ClassVar[int]
        TIME_COEFFICIENT_FIELD_NUMBER: _ClassVar[int]
        INPUT_URL_FIELD_NUMBER: _ClassVar[int]
        OUTPUT_URL_FIELD_NUMBER: _ClassVar[int]
        ANSWER_URL_FIELD_NUMBER: _ClassVar[int]
        DEBUG_STATS_FIELD_NUMBER: _ClassVar[int]
        CHECKER_STATS_FIELD_NUMBER: _ClassVar[int]
        INTERACTOR_STATS_FIELD_NUMBER: _ClassVar[int]
        reference: str
        status: EvaluationReport.Run.Status
        score: float
        cost: float
        time_usage: int
        time_limit: int
        cpu_usage: int
        cpu_limit: int
        memory_usage: int
        memory_limit: int
        time_coefficient: float
        input_url: str
        output_url: str
        answer_url: str
        debug_stats: _stats_pb2.Stats
        checker_stats: _stats_pb2.Stats
        interactor_stats: _stats_pb2.Stats
        def __init__(self, reference: _Optional[str] = ..., status: _Optional[_Union[EvaluationReport.Run.Status, str]] = ..., score: _Optional[float] = ..., cost: _Optional[float] = ..., time_usage: _Optional[int] = ..., time_limit: _Optional[int] = ..., cpu_usage: _Optional[int] = ..., cpu_limit: _Optional[int] = ..., memory_usage: _Optional[int] = ..., memory_limit: _Optional[int] = ..., time_coefficient: _Optional[float] = ..., input_url: _Optional[str] = ..., output_url: _Optional[str] = ..., answer_url: _Optional[str] = ..., debug_stats: _Optional[_Union[_stats_pb2.Stats, _Mapping]] = ..., checker_stats: _Optional[_Union[_stats_pb2.Stats, _Mapping]] = ..., interactor_stats: _Optional[_Union[_stats_pb2.Stats, _Mapping]] = ...) -> None: ...
    class MetadataEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    REFERENCE_FIELD_NUMBER: _ClassVar[int]
    ORIGIN_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    AGENT_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    ERROR_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    RUNS_FIELD_NUMBER: _ClassVar[int]
    task_id: str
    reference: str
    origin: str
    metadata: _containers.ScalarMap[str, str]
    agent: str
    signature: str
    version: int
    type: EvaluationReport.Type
    status: EvaluationReport.Status
    error_message: str
    runs: _containers.RepeatedCompositeFieldContainer[EvaluationReport.Run]
    def __init__(self, task_id: _Optional[str] = ..., reference: _Optional[str] = ..., origin: _Optional[str] = ..., metadata: _Optional[_Mapping[str, str]] = ..., agent: _Optional[str] = ..., signature: _Optional[str] = ..., version: _Optional[int] = ..., type: _Optional[_Union[EvaluationReport.Type, str]] = ..., status: _Optional[_Union[EvaluationReport.Status, str]] = ..., error_message: _Optional[str] = ..., runs: _Optional[_Iterable[_Union[EvaluationReport.Run, _Mapping]]] = ...) -> None: ...



from .ranker_pb2 import *
from .scoreboard_service_http import *
from .format_pb2 import *
from .events_pb2 import *
from .activity_pb2 import *
from .scoreboard_service_pb2 import *
from .ranker_http import *
from .scoreboard_pb2 import *



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler. DO NOT EDIT!
# See https://github.com/eolymp/contracts/tree/main/cmd/protoc-gen-python-esdk for more details.
"""Generated protocol buffer code."""

import urllib.parse
from google.protobuf import symbol_database as _symbol_database

_sym_db = _symbol_database.Default()


class ViolationServiceClient:
    def __init__(self, transport, url="https://api.eolymp.com"):
        self.transport = transport
        self.url = url

    def CreateViolation(self, request, **kwargs):
        path = "/violations"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.CreateViolationOutput"),
            **kwargs,
        )

    def UpdateViolation(self, request, **kwargs):
        path = "/violations/"+urllib.parse.quote(request.violation_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.violation_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.UpdateViolationOutput"),
            **kwargs,
        )

    def DeleteViolation(self, request, **kwargs):
        path = "/violations/"+urllib.parse.quote(request.violation_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.violation_id = ""

        return self.transport.request(
            method="DELETE",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.DeleteViolationOutput"),
            **kwargs,
        )

    def DescribeViolation(self, request, **kwargs):
        path = "/violations/"+urllib.parse.quote(request.violation_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.violation_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.DescribeViolationOutput"),
            **kwargs,
        )

    def ListViolations(self, request, **kwargs):
        path = "/violations"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.ListViolationsOutput"),
            **kwargs,
        )




from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.community import member_pb2 as _member_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RequestAdmissionInput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class RequestAdmissionOutput(_message.Message):
    __slots__ = ("required", "code")
    REQUIRED_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    required: bool
    code: str
    def __init__(self, required: bool = ..., code: _Optional[str] = ...) -> None: ...

class AcceptAdmissionInput(_message.Message):
    __slots__ = ("code",)
    CODE_FIELD_NUMBER: _ClassVar[int]
    code: str
    def __init__(self, code: _Optional[str] = ...) -> None: ...

class AcceptAdmissionOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DescribeAdmissionInput(_message.Message):
    __slots__ = ("code",)
    CODE_FIELD_NUMBER: _ClassVar[int]
    code: str
    def __init__(self, code: _Optional[str] = ...) -> None: ...

class DescribeAdmissionOutput(_message.Message):
    __slots__ = ("participant_id", "session_id", "member")
    PARTICIPANT_ID_FIELD_NUMBER: _ClassVar[int]
    SESSION_ID_FIELD_NUMBER: _ClassVar[int]
    MEMBER_FIELD_NUMBER: _ClassVar[int]
    participant_id: str
    session_id: str
    member: _member_pb2.Member
    def __init__(self, participant_id: _Optional[str] = ..., session_id: _Optional[str] = ..., member: _Optional[_Union[_member_pb2.Member, _Mapping]] = ...) -> None: ...

class WatchAdmissionInput(_message.Message):
    __slots__ = ("code",)
    CODE_FIELD_NUMBER: _ClassVar[int]
    code: str
    def __init__(self, code: _Optional[str] = ...) -> None: ...

class WatchAdmissionOutput(_message.Message):
    __slots__ = ("status",)
    class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_STATUS: _ClassVar[WatchAdmissionOutput.Status]
        ACCEPTED: _ClassVar[WatchAdmissionOutput.Status]
        EXPIRED: _ClassVar[WatchAdmissionOutput.Status]
    UNKNOWN_STATUS: WatchAdmissionOutput.Status
    ACCEPTED: WatchAdmissionOutput.Status
    EXPIRED: WatchAdmissionOutput.Status
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: WatchAdmissionOutput.Status
    def __init__(self, status: _Optional[_Union[WatchAdmissionOutput.Status, str]] = ...) -> None: ...



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.community import credit_pb2 as _credit_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateCreditInput(_message.Message):
    __slots__ = ("credit",)
    CREDIT_FIELD_NUMBER: _ClassVar[int]
    credit: _credit_pb2.Credit
    def __init__(self, credit: _Optional[_Union[_credit_pb2.Credit, _Mapping]] = ...) -> None: ...

class CreateCreditOutput(_message.Message):
    __slots__ = ("credit_id",)
    CREDIT_ID_FIELD_NUMBER: _ClassVar[int]
    credit_id: str
    def __init__(self, credit_id: _Optional[str] = ...) -> None: ...

class DeleteCreditInput(_message.Message):
    __slots__ = ("credit_id",)
    CREDIT_ID_FIELD_NUMBER: _ClassVar[int]
    credit_id: str
    def __init__(self, credit_id: _Optional[str] = ...) -> None: ...

class DeleteCreditOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ListCreditsInput(_message.Message):
    __slots__ = ("offset", "size", "filters")
    class Filter(_message.Message):
        __slots__ = ("id", "reference", "note", "amount", "active")
        ID_FIELD_NUMBER: _ClassVar[int]
        REFERENCE_FIELD_NUMBER: _ClassVar[int]
        NOTE_FIELD_NUMBER: _ClassVar[int]
        AMOUNT_FIELD_NUMBER: _ClassVar[int]
        ACTIVE_FIELD_NUMBER: _ClassVar[int]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        reference: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        note: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionString]
        amount: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionInt]
        active: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionBool]
        def __init__(self, id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., reference: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., note: _Optional[_Iterable[_Union[_expression_pb2.ExpressionString, _Mapping]]] = ..., amount: _Optional[_Iterable[_Union[_expression_pb2.ExpressionInt, _Mapping]]] = ..., active: _Optional[_Iterable[_Union[_expression_pb2.ExpressionBool, _Mapping]]] = ...) -> None: ...
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    offset: int
    size: int
    filters: ListCreditsInput.Filter
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListCreditsInput.Filter, _Mapping]] = ...) -> None: ...

class ListCreditsOutput(_message.Message):
    __slots__ = ("total", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_credit_pb2.Credit]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_credit_pb2.Credit, _Mapping]]] = ...) -> None: ...

class RedeemCreditInput(_message.Message):
    __slots__ = ("amount", "reference", "note")
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    REFERENCE_FIELD_NUMBER: _ClassVar[int]
    NOTE_FIELD_NUMBER: _ClassVar[int]
    amount: int
    reference: str
    note: str
    def __init__(self, amount: _Optional[int] = ..., reference: _Optional[str] = ..., note: _Optional[str] = ...) -> None: ...

class RedeemCreditOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DescribeCreditBalanceInput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DescribeCreditBalanceOutput(_message.Message):
    __slots__ = ("balance",)
    BALANCE_FIELD_NUMBER: _ClassVar[int]
    balance: int
    def __init__(self, balance: _Optional[int] = ...) -> None: ...



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.notify import notification_pb2 as _notification_pb2
from eolymp.notify import preferences_pb2 as _preferences_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class NotificationEvent(_message.Message):
    __slots__ = ("notification",)
    NOTIFICATION_FIELD_NUMBER: _ClassVar[int]
    notification: _notification_pb2.Notification
    def __init__(self, notification: _Optional[_Union[_notification_pb2.Notification, _Mapping]] = ...) -> None: ...

class CreateNotificationInput(_message.Message):
    __slots__ = ("notification",)
    NOTIFICATION_FIELD_NUMBER: _ClassVar[int]
    notification: _notification_pb2.Notification
    def __init__(self, notification: _Optional[_Union[_notification_pb2.Notification, _Mapping]] = ...) -> None: ...

class CreateNotificationOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DescribeNotificationInput(_message.Message):
    __slots__ = ("notification_id",)
    NOTIFICATION_ID_FIELD_NUMBER: _ClassVar[int]
    notification_id: str
    def __init__(self, notification_id: _Optional[str] = ...) -> None: ...

class DescribeNotificationOutput(_message.Message):
    __slots__ = ("notification",)
    NOTIFICATION_FIELD_NUMBER: _ClassVar[int]
    notification: _notification_pb2.Notification
    def __init__(self, notification: _Optional[_Union[_notification_pb2.Notification, _Mapping]] = ...) -> None: ...

class ReadNotificationInput(_message.Message):
    __slots__ = ("notification_id",)
    NOTIFICATION_ID_FIELD_NUMBER: _ClassVar[int]
    notification_id: str
    def __init__(self, notification_id: _Optional[str] = ...) -> None: ...

class ReadNotificationOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DeleteNotificationInput(_message.Message):
    __slots__ = ("notification_id",)
    NOTIFICATION_ID_FIELD_NUMBER: _ClassVar[int]
    notification_id: str
    def __init__(self, notification_id: _Optional[str] = ...) -> None: ...

class DeleteNotificationOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ListNotificationsInput(_message.Message):
    __slots__ = ("size", "after")
    SIZE_FIELD_NUMBER: _ClassVar[int]
    AFTER_FIELD_NUMBER: _ClassVar[int]
    size: int
    after: str
    def __init__(self, size: _Optional[int] = ..., after: _Optional[str] = ...) -> None: ...

class ListNotificationsOutput(_message.Message):
    __slots__ = ("total", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_notification_pb2.Notification]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_notification_pb2.Notification, _Mapping]]] = ...) -> None: ...

class DescribePreferencesInput(_message.Message):
    __slots__ = ("space_id",)
    SPACE_ID_FIELD_NUMBER: _ClassVar[int]
    space_id: str
    def __init__(self, space_id: _Optional[str] = ...) -> None: ...

class DescribePreferencesOutput(_message.Message):
    __slots__ = ("preferences",)
    PREFERENCES_FIELD_NUMBER: _ClassVar[int]
    preferences: _preferences_pb2.Preferences
    def __init__(self, preferences: _Optional[_Union[_preferences_pb2.Preferences, _Mapping]] = ...) -> None: ...

class UpdatePreferencesInput(_message.Message):
    __slots__ = ("patch", "space_id", "preferences")
    class Patch(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        ALL: _ClassVar[UpdatePreferencesInput.Patch]
        SUBSCRIPTIONS: _ClassVar[UpdatePreferencesInput.Patch]
        SUBSCRIPTIONS_ADD: _ClassVar[UpdatePreferencesInput.Patch]
        SUBSCRIPTIONS_REMOVE: _ClassVar[UpdatePreferencesInput.Patch]
    ALL: UpdatePreferencesInput.Patch
    SUBSCRIPTIONS: UpdatePreferencesInput.Patch
    SUBSCRIPTIONS_ADD: UpdatePreferencesInput.Patch
    SUBSCRIPTIONS_REMOVE: UpdatePreferencesInput.Patch
    PATCH_FIELD_NUMBER: _ClassVar[int]
    SPACE_ID_FIELD_NUMBER: _ClassVar[int]
    PREFERENCES_FIELD_NUMBER: _ClassVar[int]
    patch: _containers.RepeatedScalarFieldContainer[UpdatePreferencesInput.Patch]
    space_id: str
    preferences: _preferences_pb2.Preferences
    def __init__(self, patch: _Optional[_Iterable[_Union[UpdatePreferencesInput.Patch, str]]] = ..., space_id: _Optional[str] = ..., preferences: _Optional[_Union[_preferences_pb2.Preferences, _Mapping]] = ...) -> None: ...

class UpdatePreferencesOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ExecuteJobInput(_message.Message):
    __slots__ = ("job_id", "namespace", "type", "inputs")
    class InputsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    JOB_ID_FIELD_NUMBER: _ClassVar[int]
    NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    INPUTS_FIELD_NUMBER: _ClassVar[int]
    job_id: str
    namespace: str
    type: str
    inputs: _containers.ScalarMap[str, str]
    def __init__(self, job_id: _Optional[str] = ..., namespace: _Optional[str] = ..., type: _Optional[str] = ..., inputs: _Optional[_Mapping[str, str]] = ...) -> None: ...

class ExecuteJobUpdate(_message.Message):
    __slots__ = ("progress", "outputs", "logs")
    class ProgressUpdate(_message.Message):
        __slots__ = ("progress", "total")
        PROGRESS_FIELD_NUMBER: _ClassVar[int]
        TOTAL_FIELD_NUMBER: _ClassVar[int]
        progress: int
        total: int
        def __init__(self, progress: _Optional[int] = ..., total: _Optional[int] = ...) -> None: ...
    class OutputUpdate(_message.Message):
        __slots__ = ("outputs",)
        class OutputsEntry(_message.Message):
            __slots__ = ("key", "value")
            KEY_FIELD_NUMBER: _ClassVar[int]
            VALUE_FIELD_NUMBER: _ClassVar[int]
            key: str
            value: str
            def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
        OUTPUTS_FIELD_NUMBER: _ClassVar[int]
        outputs: _containers.ScalarMap[str, str]
        def __init__(self, outputs: _Optional[_Mapping[str, str]] = ...) -> None: ...
    class LoggingUpdate(_message.Message):
        __slots__ = ("chunk",)
        CHUNK_FIELD_NUMBER: _ClassVar[int]
        chunk: bytes
        def __init__(self, chunk: _Optional[bytes] = ...) -> None: ...
    PROGRESS_FIELD_NUMBER: _ClassVar[int]
    OUTPUTS_FIELD_NUMBER: _ClassVar[int]
    LOGS_FIELD_NUMBER: _ClassVar[int]
    progress: ExecuteJobUpdate.ProgressUpdate
    outputs: ExecuteJobUpdate.OutputUpdate
    logs: ExecuteJobUpdate.LoggingUpdate
    def __init__(self, progress: _Optional[_Union[ExecuteJobUpdate.ProgressUpdate, _Mapping]] = ..., outputs: _Optional[_Union[ExecuteJobUpdate.OutputUpdate, _Mapping]] = ..., logs: _Optional[_Union[ExecuteJobUpdate.LoggingUpdate, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/notify/preferences.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/notify/preferences.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x65olymp/notify/preferences.proto\x12\reolymp.notify\"\xe3\x01\n\x0bPreferences\x12>\n\rsubscriptions\x18\n \x03(\x0b\x32\'.eolymp.notify.Preferences.Subscription\x1aP\n\x0cSubscription\x12\r\n\x05topic\x18\x01 \x01(\t\x12\x31\n\x06\x64igest\x18\x02 \x01(\x0e\x32!.eolymp.notify.Preferences.Digest\"B\n\x06\x44igest\x12\x12\n\x0eUNKNOWN_DIGEST\x10\x00\x12\r\n\tIMMEDIATE\x10\x01\x12\n\n\x06HOURLY\x10\x02\x12\t\n\x05\x44\x41ILY\x10\x03\x42/Z-github.com/eolymp/go-sdk/eolymp/notify;notifyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.notify.preferences_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/notify;notify'
  _globals['_PREFERENCES']._serialized_start=51
  _globals['_PREFERENCES']._serialized_end=278
  _globals['_PREFERENCES_SUBSCRIPTION']._serialized_start=130
  _globals['_PREFERENCES_SUBSCRIPTION']._serialized_end=210
  _globals['_PREFERENCES_DIGEST']._serialized_start=212
  _globals['_PREFERENCES_DIGEST']._serialized_end=278
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/commerce/product.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/commerce/product.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.ecm import content_pb2 as eolymp_dot_ecm_dot_content__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x65olymp/commerce/product.proto\x12\x0f\x65olymp.commerce\x1a\x18\x65olymp/ecm/content.proto\"\xcf\x05\n\x07Product\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12(\n\x0b\x64\x65scription\x18\x03 \x01(\x0b\x32\x13.eolymp.ecm.Content\x12\x0e\n\x06images\x18\n \x03(\t\x12\x14\n\x0cout_of_stock\x18\x1e \x01(\x08\x12\x10\n\x08\x63urrency\x18\x14 \x01(\t\x12\x12\n\nunit_price\x18\x15 \x01(\r\x12\x36\n\nattributes\x18( \x03(\x0b\x32\".eolymp.commerce.Product.Attribute\x12\x32\n\x08variants\x18\x32 \x03(\x0b\x32 .eolymp.commerce.Product.Variant\x1ap\n\x05\x45xtra\"g\n\x05\x46ield\x12\x11\n\rUNKNOWN_FIELD\x10\x00\x12\x15\n\x11\x44\x45SCRIPTION_VALUE\x10\x01\x12\x16\n\x12\x44\x45SCRIPTION_RENDER\x10\x02\x12\x0e\n\nATTRIBUTES\x10\x03\x12\x0c\n\x08VARIANTS\x10\x04\x1a\x81\x01\n\x05Patch\"x\n\x05\x46ield\x12\x11\n\rUNKNOWN_FIELD\x10\x00\x12\x07\n\x03\x41LL\x10\x01\x12\x08\n\x04NAME\x10\x02\x12\x0f\n\x0b\x44\x45SCRIPTION\x10\x03\x12\n\n\x06IMAGES\x10\x04\x12\x0e\n\nUNIT_PRICE\x10\x05\x12\x0e\n\nATTRIBUTES\x10\x07\x12\x0c\n\x08VARIANTS\x10\x08\x1a\'\n\tAttribute\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05label\x18\x02 \x01(\t\x1a\xa8\x01\n\x07Variant\x12\n\n\x02id\x18\x01 \x01(\t\x12<\n\x06values\x18\x02 \x03(\x0b\x32,.eolymp.commerce.Product.Variant.ValuesEntry\x12\x0e\n\x06images\x18\n \x03(\t\x12\x14\n\x0cout_of_stock\x18\x1e \x01(\x08\x1a-\n\x0bValuesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x33Z1github.com/eolymp/go-sdk/eolymp/commerce;commerceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.commerce.product_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/commerce;commerce'
  _globals['_PRODUCT_VARIANT_VALUESENTRY']._loaded_options = None
  _globals['_PRODUCT_VARIANT_VALUESENTRY']._serialized_options = b'8\001'
  _globals['_PRODUCT']._serialized_start=77
  _globals['_PRODUCT']._serialized_end=796
  _globals['_PRODUCT_EXTRA']._serialized_start=340
  _globals['_PRODUCT_EXTRA']._serialized_end=452
  _globals['_PRODUCT_EXTRA_FIELD']._serialized_start=349
  _globals['_PRODUCT_EXTRA_FIELD']._serialized_end=452
  _globals['_PRODUCT_PATCH']._serialized_start=455
  _globals['_PRODUCT_PATCH']._serialized_end=584
  _globals['_PRODUCT_PATCH_FIELD']._serialized_start=464
  _globals['_PRODUCT_PATCH_FIELD']._serialized_end=584
  _globals['_PRODUCT_ATTRIBUTE']._serialized_start=586
  _globals['_PRODUCT_ATTRIBUTE']._serialized_end=625
  _globals['_PRODUCT_VARIANT']._serialized_start=628
  _globals['_PRODUCT_VARIANT']._serialized_end=796
  _globals['_PRODUCT_VARIANT_VALUESENTRY']._serialized_start=751
  _globals['_PRODUCT_VARIANT_VALUESENTRY']._serialized_end=796
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/atlas/submission_assistant_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/atlas/submission_assistant_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.ecm import node_pb2 as eolymp_dot_ecm_dot_node__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/eolymp/atlas/submission_assistant_service.proto\x12\x0c\x65olymp.atlas\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x15\x65olymp/ecm/node.proto\"g\n\x16\x44\x65\x62ugAssistanceMessage\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06locale\x18\x03 \x01(\t\x12!\n\x07message\x18\x04 \x01(\x0b\x32\x10.eolymp.ecm.Node\x12\x0e\n\x06rating\x18\x05 \x01(\x05\"D\n\x1bRequestDebugAssistanceInput\x12\x15\n\rsubmission_id\x18\x01 \x01(\t\x12\x0e\n\x06locale\x18\x02 \x01(\t\"U\n\x1cRequestDebugAssistanceOutput\x12\x35\n\x07message\x18\x02 \x01(\x0b\x32$.eolymp.atlas.DebugAssistanceMessage\"5\n\x1c\x44\x65scribeDebugAssistanceInput\x12\x15\n\rsubmission_id\x18\x01 \x01(\t\"V\n\x1d\x44\x65scribeDebugAssistanceOutput\x12\x35\n\x07message\x18\x02 \x01(\x0b\x32$.eolymp.atlas.DebugAssistanceMessage\"A\n\x18RateDebugAssistanceInput\x12\x15\n\rsubmission_id\x18\x01 \x01(\t\x12\x0e\n\x06rating\x18\x02 \x01(\x05\"\x1b\n\x19RateDebugAssistanceOutput2\xba\x04\n\x1aSubmissionAssistantService\x12\xb4\x01\n\x16RequestDebugAssistance\x12).eolymp.atlas.RequestDebugAssistanceInput\x1a*.eolymp.atlas.RequestDebugAssistanceOutput\"C\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02.\",/submissions/{submission_id}/assistant:debug\x12\xb7\x01\n\x17\x44\x65scribeDebugAssistance\x12*.eolymp.atlas.DescribeDebugAssistanceInput\x1a+.eolymp.atlas.DescribeDebugAssistanceOutput\"C\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02.\x12,/submissions/{submission_id}/assistant:debug\x12\xaa\x01\n\x13RateDebugAssistance\x12&.eolymp.atlas.RateDebugAssistanceInput\x1a\'.eolymp.atlas.RateDebugAssistanceOutput\"B\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02-\"+/submissions/{submission_id}/assistant:rateB-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.submission_assistant_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _globals['_SUBMISSIONASSISTANTSERVICE'].methods_by_name['RequestDebugAssistance']._loaded_options = None
  _globals['_SUBMISSIONASSISTANTSERVICE'].methods_by_name['RequestDebugAssistance']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002.\",/submissions/{submission_id}/assistant:debug'
  _globals['_SUBMISSIONASSISTANTSERVICE'].methods_by_name['DescribeDebugAssistance']._loaded_options = None
  _globals['_SUBMISSIONASSISTANTSERVICE'].methods_by_name['DescribeDebugAssistance']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002.\022,/submissions/{submission_id}/assistant:debug'
  _globals['_SUBMISSIONASSISTANTSERVICE'].methods_by_name['RateDebugAssistance']._loaded_options = None
  _globals['_SUBMISSIONASSISTANTSERVICE'].methods_by_name['RateDebugAssistance']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002-\"+/submissions/{submission_id}/assistant:rate'
  _globals['_DEBUGASSISTANCEMESSAGE']._serialized_start=155
  _globals['_DEBUGASSISTANCEMESSAGE']._serialized_end=258
  _globals['_REQUESTDEBUGASSISTANCEINPUT']._serialized_start=260
  _globals['_REQUESTDEBUGASSISTANCEINPUT']._serialized_end=328
  _globals['_REQUESTDEBUGASSISTANCEOUTPUT']._serialized_start=330
  _globals['_REQUESTDEBUGASSISTANCEOUTPUT']._serialized_end=415
  _globals['_DESCRIBEDEBUGASSISTANCEINPUT']._serialized_start=417
  _globals['_DESCRIBEDEBUGASSISTANCEINPUT']._serialized_end=470
  _globals['_DESCRIBEDEBUGASSISTANCEOUTPUT']._serialized_start=472
  _globals['_DESCRIBEDEBUGASSISTANCEOUTPUT']._serialized_end=558
  _globals['_RATEDEBUGASSISTANCEINPUT']._serialized_start=560
  _globals['_RATEDEBUGASSISTANCEINPUT']._serialized_end=625
  _globals['_RATEDEBUGASSISTANCEOUTPUT']._serialized_start=627
  _globals['_RATEDEBUGASSISTANCEOUTPUT']._serialized_end=654
  _globals['_SUBMISSIONASSISTANTSERVICE']._serialized_start=657
  _globals['_SUBMISSIONASSISTANTSERVICE']._serialized_end=1227
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/universe/events.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/universe/events.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.universe import space_pb2 as eolymp_dot_universe_dot_space__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x65olymp/universe/events.proto\x12\x0f\x65olymp.universe\x1a\x1b\x65olymp/universe/space.proto\"\xc8\x01\n\x11SpaceChangeRecord\x12\x38\n\x02op\x18\x01 \x01(\x0e\x32,.eolymp.universe.SpaceChangeRecord.Operation\x12%\n\x05space\x18\x02 \x01(\x0b\x32\x16.eolymp.universe.Space\"R\n\tOperation\x12\x10\n\x0cNO_OPERATION\x10\x00\x12\n\n\x06\x43REATE\x10\x01\x12\n\n\x06UPDATE\x10\x02\x12\n\n\x06\x44\x45LETE\x10\x03\x12\x0f\n\x0bSOFT_DELETE\x10\x04\x42\x33Z1github.com/eolymp/go-sdk/eolymp/universe;universeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.universe.events_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/universe;universe'
  _globals['_SPACECHANGERECORD']._serialized_start=79
  _globals['_SPACECHANGERECORD']._serialized_end=279
  _globals['_SPACECHANGERECORD_OPERATION']._serialized_start=197
  _globals['_SPACECHANGERECORD_OPERATION']._serialized_end=279
# @@protoc_insertion_point(module_scope)



import datetime

from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class User(_message.Message):
    __slots__ = ("id", "username", "email", "active", "rating", "name", "picture", "company", "occupation", "country", "city", "email_status", "birthday", "registered_on", "last_activity", "username_changed_on", "password_changed_on", "locale")
    ID_FIELD_NUMBER: _ClassVar[int]
    USERNAME_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    RATING_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    PICTURE_FIELD_NUMBER: _ClassVar[int]
    COMPANY_FIELD_NUMBER: _ClassVar[int]
    OCCUPATION_FIELD_NUMBER: _ClassVar[int]
    COUNTRY_FIELD_NUMBER: _ClassVar[int]
    CITY_FIELD_NUMBER: _ClassVar[int]
    EMAIL_STATUS_FIELD_NUMBER: _ClassVar[int]
    BIRTHDAY_FIELD_NUMBER: _ClassVar[int]
    REGISTERED_ON_FIELD_NUMBER: _ClassVar[int]
    LAST_ACTIVITY_FIELD_NUMBER: _ClassVar[int]
    USERNAME_CHANGED_ON_FIELD_NUMBER: _ClassVar[int]
    PASSWORD_CHANGED_ON_FIELD_NUMBER: _ClassVar[int]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    id: str
    username: str
    email: str
    active: bool
    rating: int
    name: str
    picture: str
    company: str
    occupation: str
    country: str
    city: str
    email_status: str
    birthday: str
    registered_on: _timestamp_pb2.Timestamp
    last_activity: _timestamp_pb2.Timestamp
    username_changed_on: _timestamp_pb2.Timestamp
    password_changed_on: _timestamp_pb2.Timestamp
    locale: str
    def __init__(self, id: _Optional[str] = ..., username: _Optional[str] = ..., email: _Optional[str] = ..., active: bool = ..., rating: _Optional[int] = ..., name: _Optional[str] = ..., picture: _Optional[str] = ..., company: _Optional[str] = ..., occupation: _Optional[str] = ..., country: _Optional[str] = ..., city: _Optional[str] = ..., email_status: _Optional[str] = ..., birthday: _Optional[str] = ..., registered_on: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., last_activity: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., username_changed_on: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., password_changed_on: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., locale: _Optional[str] = ...) -> None: ...



import datetime

from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Violation(_message.Message):
    __slots__ = ("id", "status", "type", "summary", "automatic", "participant_id", "submission_id", "created_by", "created_at", "confirmed_by", "confirmed_at")
    class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_STATUS: _ClassVar[Violation.Status]
        PENDING: _ClassVar[Violation.Status]
        CONFIRMED: _ClassVar[Violation.Status]
        CANCELLED: _ClassVar[Violation.Status]
    UNKNOWN_STATUS: Violation.Status
    PENDING: Violation.Status
    CONFIRMED: Violation.Status
    CANCELLED: Violation.Status
    class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_TYPE: _ClassVar[Violation.Type]
        OTHER: _ClassVar[Violation.Type]
        PLAGIARISM: _ClassVar[Violation.Type]
        GEN_AI_USAGE: _ClassVar[Violation.Type]
    UNKNOWN_TYPE: Violation.Type
    OTHER: Violation.Type
    PLAGIARISM: Violation.Type
    GEN_AI_USAGE: Violation.Type
    class Patch(_message.Message):
        __slots__ = ()
        class Field(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = ()
            UNSPECIFIED: _ClassVar[Violation.Patch.Field]
            SUMMARY: _ClassVar[Violation.Patch.Field]
            STATUS: _ClassVar[Violation.Patch.Field]
            AUTOMATIC: _ClassVar[Violation.Patch.Field]
        UNSPECIFIED: Violation.Patch.Field
        SUMMARY: Violation.Patch.Field
        STATUS: Violation.Patch.Field
        AUTOMATIC: Violation.Patch.Field
        def __init__(self) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    SUMMARY_FIELD_NUMBER: _ClassVar[int]
    AUTOMATIC_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_ID_FIELD_NUMBER: _ClassVar[int]
    SUBMISSION_ID_FIELD_NUMBER: _ClassVar[int]
    CREATED_BY_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    CONFIRMED_BY_FIELD_NUMBER: _ClassVar[int]
    CONFIRMED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    status: Violation.Status
    type: Violation.Type
    summary: str
    automatic: bool
    participant_id: str
    submission_id: str
    created_by: str
    created_at: _timestamp_pb2.Timestamp
    confirmed_by: str
    confirmed_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., status: _Optional[_Union[Violation.Status, str]] = ..., type: _Optional[_Union[Violation.Type, str]] = ..., summary: _Optional[str] = ..., automatic: bool = ..., participant_id: _Optional[str] = ..., submission_id: _Optional[str] = ..., created_by: _Optional[str] = ..., created_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., confirmed_by: _Optional[str] = ..., confirmed_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...



from .order_service_pb2 import *
from .product_service_pb2 import *
from .shopping_service_http import *
from .order_pb2 import *
from .shopping_service_pb2 import *
from .order_service_http import *
from .product_pb2 import *
from .price_pb2 import *
from .product_service_http import *
from .shopping_cart_pb2 import *
from .invoice_pb2 import *
from .address_pb2 import *
